#[repr(C)]pub struct ExternalPriceAccount {
pub key: Key,
pub price_per_share: u64,
pub price_mint: Pubkey,
pub allowed_to_combine: bool,
}Fields
key: Keyprice_mint: PubkeyMint of the currency we are pricing the shares against, should be same as redeem_treasury. Most likely will be USDC mint most of the time.
allowed_to_combine: boolWhether or not combination has been allowed for this vault.
Implementations
Sourceimpl ExternalPriceAccount
impl ExternalPriceAccount
pub fn from_account_info( a: &AccountInfo<'_>, ) -> Result<ExternalPriceAccount, ProgramError>